/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jclouds.openstack.neutron.v2.domain;

import java.beans.ConstructorProperties;
import java.util.Set;

import com.google.common.base.Predicate;
import org.jclouds.openstack.v2_0.domain.Link;
import org.jclouds.openstack.v2_0.domain.PaginatedCollection;

import com.google.common.collect.ImmutableSet;

/**
 * A collection of Networks
 */
public class Networks extends PaginatedCollection<Network> {
   public static final Networks EMPTY = new Networks(ImmutableSet.<Network> of(), ImmutableSet.<Link> of());

   @ConstructorProperties({"networks", "networks_links"})
   protected Networks(Iterable<Network> networks, Iterable<Link> networksLinks) {
      super(networks, networksLinks);
   }

   public static class Predicates {

      public static Predicate<Network> externalNetworks(final String availabilityZone) {
         return new Predicate<Network>() {
            @Override
            public boolean apply(Network network) {
               return availabilityZone.equals(network.getAvailabilityZone()) && network.getExternal();
            }
         };
      }

      public static Predicate<Network> namedNetworks(final Set<String> names) {
         return new Predicate<Network>() {
            @Override
            public boolean apply(Network network) {
               return names.contains(network.getName());
            }
         };
      }
   }
}
