/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jclouds.b2;

import org.jclouds.b2.domain.B2Error;
import org.jclouds.http.HttpCommand;
import org.jclouds.http.HttpResponse;
import org.jclouds.http.HttpResponseException;

import com.google.common.base.Preconditions;
import org.jclouds.javax.annotation.Nullable;

public final class B2ResponseException extends HttpResponseException {
   private final transient B2Error error;

   public B2ResponseException(HttpCommand command, HttpResponse response, B2Error error) {
      super("request " + command.getCurrentRequest().getRequestLine() + " failed with code " + response.getStatusCode()
            + ", error: " + Preconditions.checkNotNull(error, "error").toString(), command, response);
      this.error = error;
   }

   @Nullable
   public B2Error getError() {
      return error;
   }
}
