/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jclouds.packet.domain;

import java.util.Set;

import org.jclouds.json.SerializedNames;

import com.google.auto.value.AutoValue;
import com.google.common.collect.ImmutableSet;

@AutoValue
public abstract class OperatingSystem {

    public abstract String id();
    public abstract String slug();
    public abstract String name();
    public abstract String distribution();
    public abstract String version();
    public abstract Set<String> provisionableOn();

    @SerializedNames({"id", "slug", "name", "distro", "version", "provisionable_on"})
    public static OperatingSystem create(String id, String slug, String name, String distribution, String version, Set<String> provisionableOn) {
        return new AutoValue_OperatingSystem(id, slug, name, distribution, version,
                provisionableOn == null ? ImmutableSet.<String> of() : ImmutableSet.copyOf(provisionableOn)
        );
    }

    OperatingSystem() {}

}
